@@ -96,7 +96,9 @@ class DrimeClient:
 
         except requests.exceptions.HTTPError as e:
             # Try to get error message from response
-            status_code = e.response.status_code if e.response else None
+            # Note: e.response can be a Response object that evaluates to False
+            # if the status code indicates an error, so we must check "is not None"
+            status_code = e.response.status_code if e.response is not None else None
 
             # Handle common HTTP status codes with user-friendly messages
             if status_code == 401:
@@ -116,24 +118,24 @@ class DrimeClient:
             else:
                 error_msg = f"API request failed with status {status_code}"
 
-            # Try to extract more details from response body
-            try:
-                if e.response is not None and e.response.content:
-                    error_data = e.response.json()
-                    if isinstance(error_data, dict):
-                        # Try to extract error message from common fields
-                        msg = (
-                            error_data.get("message")
-                            or error_data.get("error")
-                            or error_data.get("detail")
-                        )
-                        if msg:
-                            error_msg = f"{error_msg}: {msg}"
-            except Exception:
-                # If we can't parse the error response, use the status-based message
-                pass
+                # Try to extract more details from response body
+                try:
+                    if e.response is not None and e.response.content:
+                        error_data = e.response.json()
+                        if isinstance(error_data, dict):
+                            # Try to extract error message from common fields
+                            msg = (
+                                error_data.get("message")
+                                or error_data.get("error")
+                                or error_data.get("detail")
+                            )
+                            if msg:
+                                error_msg = f"{error_msg}: {msg}"
+                except Exception:
+                    # If we can't parse the error response, use the status-based message
+                    pass
 
-            raise DrimeAPIError(error_msg) from e
+                raise DrimeAPIError(error_msg) from e
         except DrimeAPIError:
             # Re-raise our own exceptions
             raise
@@ -478,6 +480,7 @@ class DrimeClient:
     def get_file_entries(
         self,
         per_page: int = 50,
+        page: Optional[int] = None,
         deleted_only: Optional[bool] = None,
         starred_only: Optional[bool] = None,
         recent_only: Optional[bool] = None,
@@ -494,6 +497,7 @@ class DrimeClient:
 
         Args:
             per_page: How many entries to return per page (default: 50)
+            page: Page number to retrieve (1-based, default: None for page 1)
             deleted_only: Whether only trashed entries should be returned
             starred_only: Whether only starred entries should be returned
             recent_only: Whether only recent entries should be returned
@@ -512,6 +516,8 @@ class DrimeClient:
         endpoint = "/drive/file-entries"
         params: dict[str, Any] = {"perPage": per_page, "workspaceId": workspace_id}
 
+        if page is not None:
+            params["page"] = page
         if deleted_only is not None:
             params["deletedOnly"] = deleted_only
         if starred_only is not None:
