@@ -103,6 +103,41 @@ class TestSchemaValidation:
         SchemaValidationWarning.clear_warnings()
         assert not SchemaValidationWarning.has_warnings()
 
+    def test_optional_field_with_none_value(self):
+        """Test that None values for optional fields don't trigger warnings."""
+        SchemaValidationWarning.enable()
+
+        # Create a User with None value for optional field
+        data = {
+            "id": 1,
+            "email": "test@example.com",
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+            "first_name": None,  # Optional field with None value
+        }
+        User.from_dict(data)
+
+        # Should not have warnings about None values for optional fields
+        warnings = SchemaValidationWarning.get_warnings()
+        assert not any("first_name" in w and "Type mismatch" in w for w in warnings)
+
+    def test_field_type_validation(self):
+        """Test that field type validation works correctly."""
+        SchemaValidationWarning.enable()
+
+        # Create data with wrong type for email (required field)
+        data = {
+            "id": 1,
+            "email": 123,  # Should be str, not int
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+        }
+        User.from_dict(data)
+
+        warnings = SchemaValidationWarning.get_warnings()
+        assert len(warnings) > 0
+        assert any("email" in w and "Type mismatch" in w for w in warnings)
+
 
 class TestUserStatus:
     """Tests for UserStatus model."""
@@ -248,6 +283,68 @@ class TestSubscription:
 
         assert sub.plan_name == "Premium Plan"
 
+    def test_from_dict(self):
+        """Test creating Subscription from dictionary."""
+        data = {
+            "id": 1,
+            "user_id": 1,
+            "price_id": 1,
+            "gateway_name": "stripe",
+            "quantity": 1,
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+            "product_id": 1,
+            "on_grace_period": False,
+            "on_trial": False,
+            "valid": True,
+            "active": True,
+            "cancelled": False,
+        }
+        sub = Subscription.from_dict(data)
+        assert sub.id == 1
+        assert sub.gateway_name == "stripe"
+        assert sub.active is True
+
+
+class TestProduct:
+    """Tests for Product model."""
+
+    def test_format_available_space(self):
+        """Test formatting available space."""
+        product = Product(
+            id=1,
+            name="Test Plan",
+            uuid="test-uuid",
+            available_space=1073741824,  # 1 GB
+            created_at="2024-01-01",
+            updated_at="2024-01-01",
+        )
+        formatted = product.format_available_space()
+        assert "GB" in formatted or "GiB" in formatted
+
+    def test_from_dict(self):
+        """Test creating Product from dictionary."""
+        data = {
+            "id": 1,
+            "name": "Premium",
+            "uuid": "test-uuid-123",
+            "available_space": 5368709120,  # 5 GB
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+            "description": "Premium plan",
+            "feature_list": ["Feature 1", "Feature 2"],
+            "position": 1,
+            "recommended": True,
+            "free": False,
+            "hidden": False,
+        }
+        product = Product.from_dict(data)
+        assert product.id == 1
+        assert product.name == "Premium"
+        assert product.uuid == "test-uuid-123"
+        assert product.available_space == 5368709120
+        assert product.recommended is True
+
 
 class TestUser:
     """Tests for User model."""
@@ -1104,3 +1201,130 @@ class TestFileEntriesResult:
         assert entry is not None
         assert entry.id == 1
         assert result.get_by_name("nonexistent.txt") is None
+
+
+class TestAdditionalModels:
+    """Additional tests for remaining model coverage."""
+
+    def test_role_from_dict(self):
+        """Test creating Role from dictionary."""
+        data = {
+            "id": 1,
+            "name": "admin",
+            "default": True,
+            "guests": False,
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+        }
+        role = Role.from_dict(data)
+        assert role.id == 1
+        assert role.name == "admin"
+        assert role.default is True
+        assert role.guests is False
+
+    def test_permission_from_dict(self):
+        """Test creating Permission from dictionary."""
+        data = {
+            "id": 1,
+            "name": "files.download",
+            "restrictions": [],
+        }
+        perm = Permission.from_dict(data)
+        assert perm.id == 1
+        assert perm.name == "files.download"
+        assert perm.restrictions == []
+
+    def test_subscription_status_text_cancelled(self):
+        """Test status text for cancelled subscription."""
+        sub = Subscription(
+            id=1,
+            user_id=1,
+            price_id=1,
+            gateway_name="stripe",
+            quantity=1,
+            created_at="2024-01-01",
+            updated_at="2024-01-01",
+            product_id=1,
+            on_grace_period=False,
+            on_trial=False,
+            valid=False,
+            active=False,
+            cancelled=True,
+        )
+        assert sub.status_text == "Cancelled"
+
+    def test_subscription_status_text_grace_period(self):
+        """Test status text for subscription on grace period."""
+        sub = Subscription(
+            id=1,
+            user_id=1,
+            price_id=1,
+            gateway_name="stripe",
+            quantity=1,
+            created_at="2024-01-01",
+            updated_at="2024-01-01",
+            product_id=1,
+            on_grace_period=True,
+            on_trial=False,
+            valid=True,
+            active=False,
+            cancelled=False,
+        )
+        assert sub.status_text == "Grace Period"
+
+    def test_user_from_dict_with_all_fields(self):
+        """Test creating User from dictionary with all optional fields."""
+        data = {
+            "id": 1,
+            "email": "test@example.com",
+            "created_at": "2024-01-01",
+            "updated_at": "2024-01-01",
+            "first_name": "John",
+            "last_name": "Doe",
+            "display_name": "John D.",
+            "avatar": "https://example.com/avatar.png",
+            "timezone": "America/New_York",
+            "country": "US",
+            "language": "en",
+            "email_verified_at": "2024-01-01",
+            "roles": [],
+            "subscriptions": [],
+            "permissions": [],
+        }
+        user = User.from_dict(data)
+        assert user.id == 1
+        assert user.first_name == "John"
+        assert user.last_name == "Doe"
+        assert user.display_name == "John D."
+        assert user.avatar == "https://example.com/avatar.png"
+        assert user.timezone == "America/New_York"
+        assert user.country == "US"
+
+    def test_user_full_name_email_fallback(self):
+        """Test that full_name uses email username when no names provided."""
+        user = User(
+            id=1,
+            email="test@example.com",
+            created_at="2024-01-01",
+            updated_at="2024-01-01",
+        )
+        assert user.full_name == "test"
+
+    def test_subscription_plan_name_without_product(self):
+        """Test plan name when product is not provided."""
+        sub = Subscription(
+            id=1,
+            user_id=1,
+            price_id=1,
+            gateway_name="stripe",
+            quantity=1,
+            created_at="2024-01-01",
+            updated_at="2024-01-01",
+            product_id=1,
+            on_grace_period=False,
+            on_trial=False,
+            valid=True,
+            active=True,
+            cancelled=False,
+        )
+        assert sub.plan_name == "Unknown"
